@@ -102,6 +102,10 @@ pub fn read_or_die(path: &Path) -> Vec<u8> {
     }
 }
 
+fn has_utf16_byte_order_mark(bytes: &[u8]) -> bool {
+    matches!(bytes, [0xfe, 0xff, ..] | [0xff, 0xfe, ..])
+}
+
 /// Group bytes into u16 values for conversion to UTF-16, respecting
 /// the byte order mark if present.
 fn u16_from_bytes(bytes: &[u8]) -> Vec<u16> {
@@ -147,21 +151,6 @@ pub fn guess_content(bytes: &[u8]) -> ProbableFileKind {
     let mime = tree_magic_mini::from_u8(magic_bytes);
     info!("MIME type detected: {}", mime);
 
-    // This is a dirty hack to handle cases where files are obviously
-    // binary but can be still converted to UTF16 string.
-    // See test_gzip_is_binary
-    match mime {
-        "application/gzip" => return ProbableFileKind::Binary,
-        _ => {}
-    }
-
-    // If the bytes are is entirely valid UTF-16, treat them as a
-    // string.
-    let u16_values = u16_from_bytes(bytes);
-    if let Ok(valid_utf16_string) = String::from_utf16(&u16_values) {
-        return ProbableFileKind::Text(valid_utf16_string);
-    }
-
     // Use MIME type detection to guess whether a file is binary. This
     // has false positives and false negatives, so only check the MIME
     // type after allowing perfect text files (see issue #433).
@@ -169,8 +158,9 @@ pub fn guess_content(bytes: &[u8]) -> ProbableFileKind {
         // Treat pdf as binary.
         "application/pdf" => return ProbableFileKind::Binary,
         // application/* is a mix of stuff, application/json is fine
-        // but application/zip is binary that often looks text-ish to
-        // our heuristics.
+        // but application/zip is binary that often decodes as valid
+        // UTF-16.
+        "application/gzip" => return ProbableFileKind::Binary,
         "application/zip" => return ProbableFileKind::Binary,
         // Treat all image content as binary.
         v if v.starts_with("image/") => return ProbableFileKind::Binary,
@@ -183,6 +173,22 @@ pub fn guess_content(bytes: &[u8]) -> ProbableFileKind {
         _ => {}
     }
 
+    // Note that many binary files and mostly-valid UTF-8 files happen
+    // to be valid UTF-16. Decoding these as UTF-16 leads to garbage
+    // ("mojibake").
+    //
+    // To avoid this, we only try UTF-16 after we'vedone MIME type
+    // checks for binary, and we conservatively require an explicit
+    // byte order mark.
+    let u16_values = u16_from_bytes(bytes);
+    let utf16_str_result = String::from_utf16(&u16_values);
+    match utf16_str_result {
+        Ok(valid_utf16_string) if has_utf16_byte_order_mark(bytes) => {
+            return ProbableFileKind::Text(valid_utf16_string);
+        }
+        _ => {}
+    }
+
     // If the input bytes are *almost* valid UTF-8, treat them as UTF-8.
     let utf8_string = String::from_utf8_lossy(bytes).to_string();
     let num_utf8_invalid = utf8_string
