@@ -171,7 +171,6 @@ fn main() {
         Mode::Diff {
             diff_options,
             display_options,
-            missing_as_empty,
             set_exit_code,
             language_override,
             lhs_path,
@@ -238,7 +237,7 @@ fn main() {
                         &rhs_path,
                         &display_options,
                         &diff_options,
-                        missing_as_empty,
+                        false,
                         language_override,
                     );
                     print_diff_result(&display_options, &diff_result);
@@ -308,7 +307,7 @@ fn check_only_text(
 ) -> DiffResult {
     let has_changes = lhs_src != rhs_src;
 
-    return DiffResult {
+    DiffResult {
         lhs_display_path: lhs_display_path.into(),
         rhs_display_path: rhs_display_path.into(),
         file_format: file_format.clone(),
@@ -319,7 +318,7 @@ fn check_only_text(
         hunks: vec![],
         has_byte_changes: has_changes,
         has_syntactic_changes: has_changes,
-    };
+    }
 }
 
 fn diff_file_content(
@@ -333,7 +332,7 @@ fn diff_file_content(
     diff_options: &DiffOptions,
     language_override: Option<parse::guess_language::Language>,
 ) -> DiffResult {
-    let (mut lhs_src, mut rhs_src) = match (guess_content(lhs_bytes), guess_content(rhs_bytes)) {
+    let (lhs_src, rhs_src) = match (guess_content(lhs_bytes), guess_content(rhs_bytes)) {
         (ProbableFileKind::Binary, _) | (_, ProbableFileKind::Binary) => {
             return DiffResult {
                 lhs_display_path: lhs_display_path.into(),
@@ -351,16 +350,6 @@ fn diff_file_content(
         (ProbableFileKind::Text(lhs_src), ProbableFileKind::Text(rhs_src)) => (lhs_src, rhs_src),
     };
 
-    // Ignore the trailing newline, if present.
-    // TODO: highlight if this has changes (#144).
-    // TODO: factor out a string cleaning function.
-    if lhs_src.ends_with('\n') {
-        lhs_src.pop();
-    }
-    if rhs_src.ends_with('\n') {
-        rhs_src.pop();
-    }
-
     let (guess_src, guess_path) = match rhs_path {
         FileArgument::NamedPath(_) => (&rhs_src, Path::new(&rhs_display_path)),
         FileArgument::Stdin => (&rhs_src, Path::new(&lhs_display_path)),
