@@ -18,6 +18,7 @@ use std::{borrow::Borrow, ffi::OsStr, path::Path};
 /// corresponding tree-sitter parser.
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum Language {
+    Ada,
     Bash,
     C,
     Clojure,
@@ -74,6 +75,7 @@ pub enum Language {
 /// The language name shown to the user.
 pub fn language_name(language: Language) -> &'static str {
     match language {
+        Ada => "Ada",
         Bash => "Bash",
         C => "C",
         Clojure => "Clojure",
@@ -132,6 +134,7 @@ use Language::*;
 
 /// Which file extensions are associated with which languages.
 pub const LANG_EXTENSIONS: &[(Language, &[&str])] = &[
+    (Ada, &["ada", "adb", "ads"]),
     (
         Bash,
         &[
@@ -151,7 +154,7 @@ pub const LANG_EXTENSIONS: &[(Language, &[&str])] = &[
     // Treat .h as C++ rather than C. This is an arbitrary choice, but
     // C++ is more widely used than C according to
     // https://madnight.github.io/githut/
-    (CPlusPlus, &["cc", "cpp", "h", "hh", "hpp", "cxx"]),
+    (CPlusPlus, &["cc", "cpp", "h", "hh", "hpp", "ino", "cxx"]),
     (CSharp, &["cs"]),
     (Css, &["css"]),
     (Dart, &["dart"]),
@@ -349,6 +352,7 @@ fn from_emacs_mode_header(src: &str) -> Option<Language> {
             _ => "".into(),
         };
         let lang = match mode_name.to_ascii_lowercase().trim().borrow() {
+            "ada" => Some(Ada),
             "c" => Some(C),
             "clojure" => Some(Clojure),
             "csharp" => Some(CSharp),
